=== modified file 'NEWS'
--- NEWS	2012-07-09 15:23:26 +0000
+++ NEWS	2013-02-26 10:04:48 +0000
@@ -13,6 +13,10 @@
 
   * Fix searching in tree views. (Jelmer Vernooij, #928301)
 
+  * Don't try to expand options in commit messages. They've been saved from
+    previous commits and won't ever contain option references.
+    (Vincent Ladeuil, #1132719)
+
  CHANGES
 
   * bzr-notify has been removed, as it was causing regressions

=== modified file 'annotate/gannotate.py'
--- annotate/gannotate.py	2012-03-11 18:24:06 +0000
+++ annotate/gannotate.py	2012-09-02 14:49:20 +0000
@@ -279,19 +279,23 @@
         cell.set_property("xalign", 1.0)
         cell.set_property("ypad", 0)
         cell.set_property("family", "Monospace")
-        cell.set_property("cell-background-gdk",
-                          tv.get_style().bg[Gtk.StateType.NORMAL])
+        cell.set_property(
+            "cell-background-rgba",
+            tv.get_style_context().get_background_color(Gtk.StateType.NORMAL))
         col = Gtk.TreeViewColumn()
         col.set_resizable(False)
         col.pack_start(cell, True)
         col.add_attribute(cell, "text", LINE_NUM_COL)
         tv.append_column(col)
 
+        style_context = self.get_style_context()
+
         cell = Gtk.CellRendererText()
         cell.set_property("ypad", 0)
         cell.set_property("ellipsize", Pango.EllipsizeMode.END)
-        cell.set_property("cell-background-gdk",
-                          self.get_style().bg[Gtk.StateType.NORMAL])
+        cell.set_property(
+            "cell-background-rgba",
+            style_context.get_background_color(Gtk.StateType.NORMAL))
         col = Gtk.TreeViewColumn("Committer")
         col.set_resizable(True)
         col.pack_start(cell, True)
@@ -301,8 +305,9 @@
         cell = Gtk.CellRendererText()
         cell.set_property("xalign", 1.0)
         cell.set_property("ypad", 0)
-        cell.set_property("cell-background-gdk",
-                          self.get_style().bg[Gtk.StateType.NORMAL])
+        cell.set_property(
+            "cell-background-rgba",
+            style_context.get_background_color(Gtk.StateType.NORMAL))
         col = Gtk.TreeViewColumn("Revno")
         col.set_resizable(False)
         col.pack_start(cell, True)

=== modified file 'branchview/graphcell.py'
--- branchview/graphcell.py	2011-09-07 16:01:14 +0000
+++ branchview/graphcell.py	2012-09-02 14:49:20 +0000
@@ -90,7 +90,8 @@
             return self._box_size
         except AttributeError:
             pango_ctx = widget.get_pango_context()
-            font_desc = widget.get_style().font_desc
+            font_desc = widget.get_style_context().get_font(
+                Gtk.StateType.NORMAL)
             metrics = pango_ctx.get_metrics(font_desc, None)
             ascent = PANGO_PIXELS(metrics.get_ascent())
             descent = PANGO_PIXELS(metrics.get_descent())

=== modified file 'commitmsgs.py'
--- commitmsgs.py	2011-12-20 16:47:38 +0000
+++ commitmsgs.py	2013-02-26 10:04:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 by Szilveszter Farkas (Phanatic) <szilveszter.farkas@gmail.com>
+# Copyright (C) 2011, 2013 by Szilveszter Farkas (Phanatic) <szilveszter.farkas@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -35,10 +35,11 @@
         else:
             config = branch.get_config()
             self.global_message = config.get_user_option(
-                'gtk_global_commit_message')
+                'gtk_global_commit_message', expand=False)
             if self.global_message is None:
                 self.global_message = u''
-            file_messages = config.get_user_option('gtk_file_commit_messages')
+            file_messages = config.get_user_option(
+                'gtk_file_commit_messages' , expand=False)
             if file_messages: # unicode and B-encoded:
                 self.file_messages = bencode.bdecode(
                     file_messages.encode('UTF-8'))

=== modified file 'preferences/__init__.py'
--- preferences/__init__.py	2011-09-07 16:01:14 +0000
+++ preferences/__init__.py	2012-07-10 08:38:04 +0000
@@ -19,7 +19,6 @@
 from bzrlib.config import GlobalConfig
 from bzrlib.plugins.gtk.preferences.identity import IdentityPage
 from bzrlib.plugins.gtk.preferences.plugins import PluginsPage
-from bzrlib.plugins.gtk.preferences.notifications import NotificationsPage
 
 class PreferencesWindow(Gtk.Dialog):
     """Displays global preferences windows."""
@@ -55,8 +54,7 @@
 
     def _create_pages(self):
         return [("Identity", IdentityPage(self.config)),
-                ("Plugins", PluginsPage()),
-                ("Notifications", NotificationsPage(self.config))]
+                ("Plugins", PluginsPage())]
 
     def display(self):
         self.window.show_all()

=== removed file 'preferences/notifications.py'
--- preferences/notifications.py	2011-09-05 03:44:26 +0000
+++ preferences/notifications.py	1970-01-01 00:00:00 +0000
@@ -1,79 +0,0 @@
-# Copyright (C) 2008 Jelmer Vernooij <jelmer@samba.org>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-from gi.repository import Gtk
-
-import bzrlib.plugins.gtk
-from bzrlib.plugins.gtk.notify import (
-    has_avahi,
-    has_dbus,
-    )
-
-
-def has_email():
-    return (getattr(bzrlib.plugins, "email", None) is not None)
-
-def has_cia():
-    return (getattr(bzrlib.plugins, "cia", None) is not None)
-
-
-class NotificationsPage(Gtk.VBox):
-
-    def __init__(self, config, homogeneous=False, spacing=6):
-        self.config = config
-        super(NotificationsPage, self).__init__(
-            homogeneous=homogeneous, spacing=spacing)
-        self.set_spacing(spacing) # The vertical one
-
-        lan_frame = Gtk.Frame(label="LAN Notifications")
-
-        lan_vbox = Gtk.VBox()
-        lan_frame.add(lan_vbox)
-
-        self.gateway_to_lan = Gtk.CheckButton("_Gateway to LAN")
-        lan_vbox.pack_start(self.gateway_to_lan, False, False, 0)
-        self.gateway_to_lan.set_sensitive(has_dbus())
-
-        self.announce_on_lan = Gtk.CheckButton("_Announce on LAN")
-        lan_vbox.pack_start(self.announce_on_lan, False, False, 0)
-        self.announce_on_lan.set_sensitive(has_avahi())
-
-        self.pack_start(lan_frame, False, False, 0)
-
-        email_frame = Gtk.Frame(label="E-mail notifications")
-
-        email_hbox = Gtk.HBox()
-        self.send_email = Gtk.CheckButton("Send _E-Mail to")
-        email_hbox.pack_start(self.send_email, False, False, 0)
-        self.send_email_to = Gtk.Entry()
-        email_hbox.pack_start(self.send_email_to, False, False, 0)
-
-        email_frame.add(email_hbox)
-        email_frame.set_sensitive(has_email())
-
-        self.pack_start(email_frame, False, False, 0)
-
-        cia_frame = Gtk.Frame(label="CIA notifications")
-
-        cia_user_hbox = Gtk.HBox()
-        cia_user_hbox.pack_start(Gtk.Label("Author name"), False, False, 0)
-        self.cia_user = Gtk.Entry()
-        cia_user_hbox.pack_start(self.cia_user, False, False, 0)
-
-        cia_frame.add(cia_user_hbox)
-        cia_frame.set_sensitive(has_cia())
-
-        self.pack_start(cia_frame, False, False, 0)

=== modified file 'tests/test_commit.py'
--- tests/test_commit.py	2012-03-22 17:14:22 +0000
+++ tests/test_commit.py	2013-02-26 10:04:48 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007, 2008 John Arbash Meinel <john@arbash-meinel.com>
+# Copyright (C) 2007, 2008, 2009, 2011, 2012, 2013 John Arbash Meinel <john@arbash-meinel.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -1185,8 +1185,10 @@
             'post_uncommit', commitmsgs.save_commit_messages, None)
 
     def _get_file_info_dict(self, rank):
-        file_info = [dict(path='a', file_id='a-id', message='a msg %d' % rank),
-                     dict(path='b', file_id='b-id', message='b msg %d' % rank)]
+        file_info = [dict(path='a', file_id='a-id',
+                          message='a {msg} %d' % rank),
+                     dict(path='b', file_id='b-id',
+                          message='b msg %d' % rank)]
         return file_info
 
     def _get_file_info_revprops(self, rank):
@@ -1194,10 +1196,12 @@
         return {'file-info': bencode.bencode(file_info_prop).decode('UTF-8')}
 
     def _get_commit_message(self):
-        return self.config.get_user_option('gtk_global_commit_message')
+        return self.config.get_user_option(
+            'gtk_global_commit_message', expand=False)
 
     def _get_file_commit_messages(self):
-        return self.config.get_user_option('gtk_file_commit_messages')
+        return self.config.get_user_option(
+            'gtk_file_commit_messages', expand=False)
 
 
 class TestUncommitHook(TestSavedCommitMessages):
@@ -1219,29 +1223,31 @@
     def test_uncommit_one_by_one(self):
         uncommit.uncommit(self.tree.branch, tree=self.tree)
         self.assertEquals(u'three', self._get_commit_message())
-        self.assertEquals(u'd4:a-id7:a msg 34:b-id7:b msg 3e',
+        self.assertEquals(u'd4:a-id9:a {msg} 34:b-id7:b msg 3e',
                           self._get_file_commit_messages())
 
         uncommit.uncommit(self.tree.branch, tree=self.tree)
         self.assertEquals(u'two\n******\nthree', self._get_commit_message())
-        self.assertEquals(u'd4:a-id22:a msg 2\n******\na msg 3'
+        self.assertEquals(u'd4:a-id26:a {msg} 2\n******\na {msg} 3'
                           '4:b-id22:b msg 2\n******\nb msg 3e',
                           self._get_file_commit_messages())
 
         uncommit.uncommit(self.tree.branch, tree=self.tree)
         self.assertEquals(u'one\n******\ntwo\n******\nthree',
                           self._get_commit_message())
-        self.assertEquals(u'd4:a-id37:a msg 1\n******\na msg 2\n******\na msg 3'
-                          '4:b-id37:b msg 1\n******\nb msg 2\n******\nb msg 3e',
-                          self._get_file_commit_messages())
+        self.assertEquals(
+            u'd4:a-id43:a {msg} 1\n******\na {msg} 2\n******\na {msg} 3'
+            '4:b-id37:b msg 1\n******\nb msg 2\n******\nb msg 3e',
+            self._get_file_commit_messages())
 
     def test_uncommit_all_at_once(self):
         uncommit.uncommit(self.tree.branch, tree=self.tree, revno=1)
         self.assertEquals(u'one\n******\ntwo\n******\nthree',
                           self._get_commit_message())
-        self.assertEquals(u'd4:a-id37:a msg 1\n******\na msg 2\n******\na msg 3'
-                          '4:b-id37:b msg 1\n******\nb msg 2\n******\nb msg 3e',
-                          self._get_file_commit_messages())
+        self.assertEquals(
+            u'd4:a-id43:a {msg} 1\n******\na {msg} 2\n******\na {msg} 3'
+            '4:b-id37:b msg 1\n******\nb msg 2\n******\nb msg 3e',
+            self._get_file_commit_messages())
 
 
 class TestReusingSavedCommitMessages(TestSavedCommitMessages, QuestionHelpers):
@@ -1255,7 +1261,8 @@
         self.tree.add(['a'], ['a-id'])
         self.tree.add(['b'], ['b-id'])
         rev1 = self.tree.commit('one', revprops=self._get_file_info_revprops(1))
-        rev2 = self.tree.commit('two', revprops=self._get_file_info_revprops(2))
+        rev2 = self.tree.commit('two{x}',
+                                revprops=self._get_file_info_revprops(2))
         uncommit.uncommit(self.tree.branch, tree=self.tree)
         self.build_tree_contents([('tree/a', 'new a content\n'),
                                   ('tree/b', 'new b content'),])
@@ -1270,16 +1277,16 @@
 
     def test_setup_saved_messages(self):
         # Check the initial setup
-        self.assertEquals(u'two', self._get_commit_message())
-        self.assertEquals(u'd4:a-id7:a msg 24:b-id7:b msg 2e',
+        self.assertEquals(u'two{x}', self._get_commit_message())
+        self.assertEquals(u'd4:a-id9:a {msg} 24:b-id7:b msg 2e',
                           self._get_file_commit_messages())
 
     def test_messages_are_reloaded(self):
         dlg = self._get_commit_dialog(self.tree)
-        self.assertEquals(u'two', dlg._get_global_commit_message())
+        self.assertEquals(u'two{x}', dlg._get_global_commit_message())
         self.assertEquals(([u'a', u'b'],
                            [{ 'path': 'a',
-                             'file_id': 'a-id', 'message': 'a msg 2',},
+                             'file_id': 'a-id', 'message': 'a {msg} 2',},
                            {'path': 'b',
                             'file_id': 'b-id', 'message': 'b msg 2',}],),
                           dlg._get_specific_files())
@@ -1294,8 +1301,8 @@
         dlg = self._get_commit_dialog(self.tree)
         self._set_question_yes(dlg) # Save messages
         dlg._do_cancel()
-        self.assertEquals(u'two', self._get_commit_message())
-        self.assertEquals(u'd4:a-id7:a msg 24:b-id7:b msg 2e',
+        self.assertEquals(u'two{x}', self._get_commit_message())
+        self.assertEquals(u'd4:a-id9:a {msg} 24:b-id7:b msg 2e',
                           self._get_file_commit_messages())
 
     def test_messages_are_cleared_on_cancel_if_required(self):

=== removed file 'tests/test_notify.py'
--- tests/test_notify.py	2012-02-19 15:00:34 +0000
+++ tests/test_notify.py	1970-01-01 00:00:00 +0000
@@ -1,64 +0,0 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2012 Curtis C. Hovey <sinzui.is@verizon.net>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-import os
-import subprocess
-
-from bzrlib import tests
-from bzrlib.plugins.gtk.notify import NotifyPopupMenu
-
-
-class FakeNotifyPopupMenu(NotifyPopupMenu):
-
-    SHOW_WIDGETS = False
-
-
-class NotifyPopupMenuTestCase(tests.TestCase):
-
-    def test_init(self):
-        menu = FakeNotifyPopupMenu()
-        items = menu.get_children()
-        self.assertEqual(8, len(items))
-        self.assertEqual('_Gateway to LAN', items[0].props.label)
-        self.assertEqual('Announce _branches on LAN', items[2].props.label)
-        self.assertEqual('gtk-preferences', items[4].props.label)
-        self.assertEqual('gtk-about', items[5].props.label)
-        self.assertEqual('gtk-quit', items[7].props.label)
-
-
-class BzrNotifyTestCase(tests.TestCase):
-
-    def setUp(self):
-        top = os.path.abspath(os.path.join(
-            os.path.dirname(__file__), os.pardir))
-        self.script = os.path.join(top, 'bzr-notify')
-        self.env = dict(os.environ)
-        self.env['BZR_PLUGINS_AT'] = 'gtk@%s' % top
-        super(BzrNotifyTestCase, self).setUp()
-
-    def test_smoketest(self):
-        # This is a smoke test to verify the process starts.
-        # The logic of the module must be moved into notify.py
-        # where it can be properly tested.
-        bzr_notify = subprocess.Popen(
-            [self.script, 'test'],
-            stdout=subprocess.PIPE, stderr=subprocess.PIPE, env=self.env)
-        stdout, stderr = bzr_notify.communicate()
-        self.assertEqual('', stdout)
-        self.assertTrue(
-            stderr in (
-            '', 'ERROR:root:Could not find any typelib for AppIndicator3\n'))

=== modified file 'viz/branchwin.py'
--- viz/branchwin.py	2012-03-01 21:29:00 +0000
+++ viz/branchwin.py	2014-11-25 15:34:07 +0000
@@ -336,12 +336,6 @@
         align.add(self.treeview)
         # user-configured size
         size = self._load_size('viz-graph-size')
-        if size:
-            width, height = size
-            align.set_size_request(width, height)
-        else:
-            (width, height) = self.get_size()
-            align.set_size_request(width, int(height / 2.5))
         self._save_size_on_destroy(align, 'viz-graph-size')
         align.show()
 

